@@ -18,9 +18,7 @@ class FriendCode:
             param = param.__str__()
 
         if isinstance(param, str):
-            if '-' in param:
-                param = [int(part) for part in re.match('^(\\d{4})-(\\d{4})-(\\d{4})$', param).group(1, 2, 3)]
-            else:
+            if param.isnumeric():
                 if len(param) < 9 or len(param) > 12:
                     raise ValueError(f'The FriendCode in int form should be 9-12 digits long, '
                                      f'actually {len(param)}.')
@@ -29,6 +27,8 @@ class FriendCode:
                     int(param[-8:-4]),
                     int(param[-4:])
                 ]
+            else:
+                param = [int(part) for part in re.search(r"\(?(SW|FC|sw|fc)?\s*([:\-=])?\s?(\d{4})\s*([- ._/=])\s*(\d{4})\s*([- ._/=])\s*(\d{4})\s*\)?", param).group(3, 5, 7)]
 
         if len(param) != 3:
             raise ValueError('FriendCode should be 3 ints.')
@@ -59,7 +59,7 @@ class FriendCode:
                 and self.fc_short_3 == other.fc_short_3)
 
     @staticmethod
-    def from_dict(obj: Union[dict, list, str]) -> 'FriendCode':
+    def from_serialized(obj: Union[dict, list, str]) -> 'FriendCode':
         if isinstance(obj, list) or isinstance(obj, str):
             return FriendCode(obj)
         elif isinstance(obj, dict):
