@@ -2,6 +2,8 @@ import logging
 from typing import Optional, List, Union
 from uuid import UUID, uuid4
 
+from slapp_py.core_classes.simple_source import SimpleSource
+
 from slapp_py.core_classes.battlefy import Battlefy
 from slapp_py.core_classes.discord import Discord
 from slapp_py.core_classes.friend_code_handler import FriendCodeHandler
@@ -136,25 +138,24 @@ class Player:
         """Order PlusMembership by date, get the last (most recent) or None"""
         return (sorted(self.plus_membership, key=lambda pm: pm.date)[-1]) if self.plus_membership else None
 
-    def filter_to_source(self, source_id: Union[str, UUID]) -> 'Player':
+    def filter_to_source(self, source_id: SimpleSource) -> 'Player':
         """Filter this Player instance down to the components made by a sources id."""
-        search_uuid = source_id if isinstance(source_id, UUID) else UUID(source_id)
         return Player(
-            names=[name for name in self.names if search_uuid in name.sources],
-            teams_information=self.teams_information.filter_to_source(search_uuid),
-            battlefy=self.battlefy.filter_to_source(search_uuid),
-            discord=self.discord.filter_to_source(search_uuid),
-            fc_information=self.fc_information.filter_to_source(search_uuid),
+            names=[name for name in self.names if source_id in name.sources],
+            teams_information=self.teams_information.filter_to_source(source_id),
+            battlefy=self.battlefy.filter_to_source(source_id),
+            discord=self.discord.filter_to_source(source_id),
+            fc_information=self.fc_information.filter_to_source(source_id),
             skill=None,
-            plus_membership=[name for name in self.plus_membership if search_uuid in name.sources],
-            sendou_profiles=[name for name in self.sendou_profiles if search_uuid in name.sources],
-            twitch_profiles=[name for name in self.twitch_profiles if search_uuid in name.sources],
-            twitter_profiles=[name for name in self.twitter_profiles if search_uuid in name.sources],
+            plus_membership=[name for name in self.plus_membership if source_id in name.sources],
+            sendou_profiles=[name for name in self.sendou_profiles if source_id in name.sources],
+            twitch_profiles=[name for name in self.twitch_profiles if source_id in name.sources],
+            twitter_profiles=[name for name in self.twitter_profiles if source_id in name.sources],
             weapons=None,
             country=self.country,
             top500=self.top500,
-            pronoun=self.pronoun if self.pronoun and (self.pronoun.source == search_uuid) else None,
-            guid=self.guid)
+            pronoun=self.pronoun if self.pronoun and (self.pronoun.source == source_id) else None,
+            guid=uuid4())
 
     @property
     def sources(self):
