@@ -1,7 +1,7 @@
 import datetime
 from typing import Optional, Union, List
-from uuid import UUID
 
+from slapp_py.core_classes.simple_source import SimpleSource
 from slapp_py.core_classes.socials.social import Social
 
 PLUS_BASE_ADDRESS = "sendou.ink/plus/history/"
@@ -10,7 +10,7 @@ PLUS_BASE_ADDRESS = "sendou.ink/plus/history/"
 class PlusMembership(Social):
     def __init__(self,
                  handle: Optional[str] = None,
-                 sources: Union[None, UUID, List[UUID]] = None):
+                 sources: Union[None, SimpleSource, List[SimpleSource]] = None):
         super().__init__(
             value=handle,
             sources=sources,
