@@ -1,6 +1,6 @@
 from typing import Optional, Union, List
-from uuid import UUID
 
+from slapp_py.core_classes.simple_source import SimpleSource
 from slapp_py.core_classes.socials.social import Social
 
 TWITCH_BASE_ADDRESS = "twitch.tv"
@@ -9,7 +9,7 @@ TWITCH_BASE_ADDRESS = "twitch.tv"
 class Twitch(Social):
     def __init__(self,
                  handle: Optional[str] = None,
-                 sources: Union[None, UUID, List[UUID]] = None):
+                 sources: Union[None, SimpleSource, List[SimpleSource]] = None):
         super().__init__(
             value=handle,
             sources=sources,
